==> logging-0.1.0-20201019.144758-1.jar: META-INF/leiningen/signal-ai/logging/README.md <==
# signal-logging

Logging is hard - https://signal-ai.getoutline.com/doc/logging-oiwQo3JNFl

This library attempts to pave a road so you have less to do. It implements zero code so dependency hell is the only risk.

## Usage

[![Clojars Project](https://img.shields.io/clojars/v/signal.logging.svg)](https://clojars.org/signal.logging)

Include this libary in your project.clj
```
[signal.logging "0.1.0-SNAPSHOT"]
```

Then when you need to log something, call out to [tools.logging](https://github.com/clojure/tools.logging) as you normally would:
```clj
(require '[clojure.tools.logging :as log])

(log/info "hello world")
```

### Configure the log level
With this library you don't need to worry about writing your own `logback.xml` files. You can simply configure the log level using an environment variable:
```
LOG_LEVEL=DEBUG lein repl
```

## When to not use this library
If this configuration is too simple, this library is potentially not for you. You can write your own `logback.xml` and configure this at runtime with `java -Dlogback.configurationFile=/path/to/config.xml -jar app.jar` but it will probably make your build even more complicated.

## Future enhancements

### Timbre?
Does [Timbre](https://github.com/ptaoussanis/timbre) provide a better alternative to logging?

### Structured logging?
AWS Cloudwatch logs will parse JSON formatted logs to make it even easier to search over - https://aws.amazon.com/about-aws/whats-new/2015/01/20/amazon-cloudwatch-logs-json-log-format-support/
Logback supports logging JSON - https://medium.com/@krishankantsinghal/structured-logging-why-and-how-to-achieve-in-java-33974d22accb

Still to be tested if these two marry up in practice like they do in theory

## License

Copyright © 2020 FIXME

This program and the accompanying materials are made available under the
terms of the Eclipse Public License 2.0 which is available at
http://www.eclipse.org/legal/epl-2.0.

This Source Code may also be made available under the following Secondary
Licenses when the conditions for such availability set forth in the Eclipse
Public License, v. 2.0 are satisfied: GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or (at your
option) any later version, with the GNU Classpath Exception which is available
at https://www.gnu.org/software/classpath/license.html.

==> logging-0.1.2-20210409.170958-2.jar: META-INF/leiningen/signal-ai/logging/README.md <==
# signal-logging

Logging is hard - https://signal-ai.getoutline.com/doc/logging-oiwQo3JNFl

This library attempts to pave a road so you have less to do. It implements zero code so dependency hell is the only risk.

## Usage
[![Clojars Project](https://img.shields.io/clojars/v/signal-ai/logging.svg)](https://clojars.org/signal-ai/logging)

1. Include this libary in your project.clj
```
[signal-ai/logging "0.1.0-SNAPSHOT"]
```

2. Exclude any transitive dependencies you might have on logging libraries by [adding these exlusions to your project.clj](https://github.com/signal-ai/signal-logging-clj/blob/master/project.clj#L16)

3. Then when you need to log something, call out to [tools.logging](https://github.com/clojure/tools.logging) as you normally would:
```clj
(require '[clojure.tools.logging :as log])

(log/info "hello world")
```

### Configure the log level
With this library you don't need to worry about writing your own `logback.xml` files. You can simply configure the log level using an environment variable:
```
LOG_LEVEL=DEBUG lein repl
```

## When to not use this library
If this configuration is too simple, this library is potentially not for you. You can write your own `logback.xml` and configure this at runtime with `java -Dlogback.configurationFile=/path/to/config.xml -jar app.jar` but it will probably make your build even more complicated.

## Future enhancements

### Timbre?
Does [Timbre](https://github.com/ptaoussanis/timbre) provide a better alternative to logging?

### Structured logging?
AWS Cloudwatch logs will parse JSON formatted logs to make it even easier to search over - https://aws.amazon.com/about-aws/whats-new/2015/01/20/amazon-cloudwatch-logs-json-log-format-support/
Logback supports logging JSON - https://medium.com/@krishankantsinghal/structured-logging-why-and-how-to-achieve-in-java-33974d22accb

Still to be tested if these two marry up in practice like they do in theory

## License

Copyright © 2020 FIXME

This program and the accompanying materials are made available under the
terms of the Eclipse Public License 2.0 which is available at
http://www.eclipse.org/legal/epl-2.0.

This Source Code may also be made available under the following Secondary
Licenses when the conditions for such availability set forth in the Eclipse
Public License, v. 2.0 are satisfied: GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or (at your
option) any later version, with the GNU Classpath Exception which is available
at https://www.gnu.org/software/classpath/license.html.
